Modules
Structs
- Konfig
Manager - The main manager in konfig-rust, this is intended to be created near the start of your program, and destroyed by closing it
- Konfig
Options - Used for configuring
KonfigManager
Enums
- Konfig
Error - This is the error enum for konfig-rust, it contains all possible errors returned by konfig-rust
Traits
- Konfig
Section - This is the trait allowing a struct to be registered as a section and managed by
KonfigManager