pub struct KonfigOptions {
pub format: Format,
pub auto_save: bool,
pub use_callbacks: bool,
pub config_path: String,
}Expand description
Used for configuring KonfigManager
Fields
format: FormatThe format KonfigManager is supposed to use for the config file, possible options are in the Format enum
auto_save: boolIf true will try to save data to the config file on panic and SIGINT and SIGTERM (currently noop due to rust lifetime issues)
use_callbacks: boolWhether to call the validate and on_load callbacks when loading the data from file
config_path: StringPath to the file used for configuration, if the file does not exist it will be created, the path can be absolute or relative